<?php

namespace Waggybytes\SimplyRemindMe\Library\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;
use Waggybytes\SimplyRemindMe\Library\Localisation\DateTimeHandler;
use Waggybytes\SimplyRemindMe\Library\Localisation\DateTimeHandlerFormatter;

class UserSubscription extends Model
{
    use HasFactory, SoftDeletes;

    protected $casts = [
        'starts_at' => 'datetime',
        'ends_at' => 'datetime'
    ];

    protected $fillable = [
        'starts_at',
        'ends_at'
    ];

    public function subscription()
    {
        return $this->belongsTo(Subscription::class);
    }

    public function toArray()
    {
        $data = parent::toArray();

        $data['ends_at'] = DateTimeHandler::using($this->ends_at)
            ->convertTimezone()->toUser($this->user)
            ->format()->toCustom(DateTimeHandlerFormatter::API_DATE_FORMAT);
        $data['starts_at'] = DateTimeHandler::using($this->starts_at)
            ->convertTimezone()->toUser($this->user)
            ->format()->toCustom(DateTimeHandlerFormatter::API_DATE_FORMAT);

        return $data;
    }

    public function user()
    {
        return $this->belongsTo(User::class);
    }
}
